#!/usr/bin/env python3
# -*- coding: utf-8 -*-
""" Regex Extract
    ---
    ReExtract - A wrapper class to process a regex pattern, apply to a text file, and return the first string match. Optionally, a default may be used when no match is found. Logging and error handling are included.

    `file_name` (required str) - a text io stream containing the `pattern`

    `pattern` (optional re.Pattern) - a precompiled regex `pattern`

    `search_string` (optional str) - a raw string containing a regex pattern

    `flags` (optional int) - flags used for regex operations

    `default` (optional str) - a default value returned if `pattern` is not found

    Example:
    ```
    RE_VERSION: re.Pattern = re.compile(
        pattern= r'^__version__\s?=\s?[\'"]([^\'"]*)[\'"]',
        flags=DEFAULT_RE_FLAGS)

    result = ReExtract(
        file_name="VERSION.txt",
        pattern=RE_VERSION,
        default="0.0.1"
        )

    ```

    No Pattern Provided
    ---

    If no `pattern` is provided, a re.Pattern object is created from the `search_string` and `flags` arguments. Otherwise, these two arguments are ignored. (flags are not available at all when passing a precompiled re.Pattern object since they are compiled into the re.Pattern object.)

    Example:
    ```
    result = ReExtract(
        file_name="VERSION.txt",
        search_string=r'^__version__\s?=\s?[\'"]([^\'"]*)[\'"]',
        flags=re.MULTILINE | re.IGNORECASE
        default="0.0.1"
        )

    ```
    Errors:
    ---
    - if there is a file error, `Re_File_Error` is raised
    - if there is a matching error, the `default` is returned
    - if there is a matching error and no default is provided, a `Re_Value_Error` is raised

    AutoSys
    ---
    Part of the [AutoSys][1] package

    Copyright (c) 2018 [Michael Treanor][2]

    AutoSys is licensed under the [MIT License][3]

    [1]: https://www.github.com/skeptycal/autosys
    [2]: https://www.twitter.com/skeptycal
    [3]: https://opensource.org/licenses/MIT
    """

# 'package imports'
import autosys.regex_utils

from autosys.regex_utils import *


@dataclass(repr=False)
class ReExtract:
    """ Regex Extract
        ---
        A wrapper class to process a regex pattern, apply to a text file, and return the first string match. Optionally, a default may be used when no match is found. Logging and error handling are included.

        `file_name` (required str) - a text io stream containing the `pattern`

        `pattern` (optional re.Pattern) - a precompiled regex `pattern`

        `search_string` (optional str) - a raw string containing a regex pattern

        `flags` (optional int) - flags used for regex operations

        `default` (optional str) - a default value returned if `pattern` is not found

        Example:
        ```
        RE_VERSION: re.Pattern = re.compile(
            pattern= r'^__version__\s?=\s?[\'"]([^\'"]*)[\'"]',
            flags=DEFAULT_RE_FLAGS)

        result = ReExtract(
            file_name="VERSION.txt",
            pattern=RE_VERSION,
            default="0.0.1"
            )

        ```

        No Pattern Provided
        ---

        If no `pattern` is provided, a re.Pattern object is created from the `search_string` and `flags` arguments. Otherwise, these two arguments are ignored. (flags are not available at all when passing a precompiled re.Pattern object since they are compiled into the re.Pattern object.)

        Example:
        ```
        result = ReExtract(
            file_name="VERSION.txt",
            search_string=r'^__version__\s?=\s?[\'"]([^\'"]*)[\'"]',
            flags=re.MULTILINE | re.IGNORECASE
            default="0.0.1"
            )

        ```
        Errors:
        ---
        - if there is a file error, `Re_File_Error` is raised
        - if there is a matching error, the `default` is returned
        - if there is a matching error and no default is provided, a `Re_Value_Error` is raised

        AutoSys
        ---
        Part of the [AutoSys][1] package

        Copyright (c) 2018 [Michael Treanor][2]

        AutoSys is licensed under the [MIT License][3]

        [1]: https://www.github.com/skeptycal/autosys
        [2]: https://www.twitter.com/skeptycal
        [3]: https://opensource.org/licenses/MIT
        """

    file_name: str
    pattern: re.Pattern = None
    default: str = ""
    search_string: str = ""
    flags: int = DEFAULT_RE_FLAGS
    _result: Field = field(default="", init=False)
    _path_name: Field = field(init=False)

    def __post_init__(self):
        self._path_name = Path(self.file_name)
        if not self.pattern:
            self.pattern = re.compile(pattern=self.pattern, flags=self.flags)
        self._path_name = Path(self.file_name).resolve()

    def _get_file_contents(self, as_list: bool = False) -> (str, List):
        """ Return text file contents as one string.

            as_list - if True, return contents as a list of lines

            Wrapper for logging and error handling of file opening. """
        fh: TextIOWrapper = None
        try:
            with open(self.file_name, "rt") as fh:
                log.info(f"Opening file '{self.file_name}' go get contents.")
                if as_list:
                    log.info(
                        f"Returning list of lines from text file '{self.file_name}'."
                    )
                    return fh.readlines()
                log.info(
                    f"Returning contents of text file '{self.file_name}'.")
                return fh.read()
        except Exception as e:
            msg = f"File error while opening file '{self.file_name}'{NL}{e.args}"
            log.error(msg, e)
            raise Re_File_Error(msg, e)

    def _re_get_file_data(self) -> (str):
        """ Return the first match for regex `pattern` from `file_name`
        else `default` if it exists. """
        data: str = self._get_file_contents()
        try:
            result = self.pattern.search(data).groups()[0] or self.default
        except (ValueError, KeyError, AttributeError, TypeError) as e:
            if self.default:
                return self.default
            raise Re_Value_Error(
                f"Pattern '{pattern}' not found in file '{file_name}'", e)
        except Exception as e:
            log(e)
            raise Re_Value_Error(
                f"Error occurred while searching for pattern '{pattern}' in file '{file_name}'",
                e,
            )
        finally:
            return str(result)

    def __str__(self):
        if not self._result:
            self._result = self._re_get_file_data()
        return str(self._result)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

""" amazon_scraper.py

Usage:
  amazon_scraper.py <url> [-o=<file_name>] [--format=<json|csv|txt|html>] [--log=<True|False>]
  amazon_scraper.py <search_string> [-o=<file_name>] [--format=<json|csv|txt|html>] [--log=<True|False>]
  amazon_scraper.py [start|stop|config|test] <service_name> [--args=<args>] [--log=<True|False>]
  amazon_scraper.py (-h | --help)
  amazon_scraper.py --version

Options:
  --output=<file_name>              Output file     [default: url-based]
  --format=<json|csv|txt|html>      Output format   [default: json]
  --args=<args>                     Arguments passed to automation services
  --log=<True|False>                Log activity to file log
  -h --help                         Show this screen.
  --version                         Show version.

Scrape the Amazon.com website for specific data and log it in the specified
format. Automation services are also available.

******************************************************************************

 `AutoSys` package
        copyright (c) 2018 Michael Treanor
        https://www.github.com/skeptycal/autosys
        https://www.twitter.com/skeptycal

    `AutoSys` is licensed under the `MIT License
        `<https://opensource.org/licenses/MIT>`

"""

# 'Standard Library'
import sys
import threading
# builtins
import time

from dataclasses import dataclass
from datetime import datetime
from multiprocessing import Manager, Pool, Process, Queue

# 'package imports'
from autosys.text_utils.nowandthen import now

# 'third party'
import pandas as pd
# third party packages
import requests

from bs4 import BeautifulSoup

__author__ = "Michael Treanor"
__email__ = "skeptycal@gmail.com"
__version__ = "0.1.0"

# use proxies in requests so as to proxy your request via a proxy server
# as some sites may block the IP if traffic generated by an IP is too high
proxies = {
    "http": "http://134.119.205.253:8080",
    "https": "http://134.119.205.253:8080",
}
startTime = time.time()
qcount = 0
products = []  # List to store name of the product
prices = []  # List to store price of the product
ratings = []  # List to store ratings of the product
no_pages = 20


@dataclass
class Items:
    quantity: int
    name: str
    price: int
    rating: float


class ItemList(list):
    url: str
    query: str
    datetime: datetime = now()


def get_data(pageNo, q):
    headers = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:66.0) Gecko/20100101 Firefox/66.0",
        "Accept-Encoding": "gzip, deflate",
        "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8",
        "DNT": "1",
        "Connection": "close",
        "Upgrade-Insecure-Requests": "1",
    }

    r = requests.get(
        "https://www.amazon.com/s?k=laptops&page=" + str(pageNo),
        headers=headers,
    )  # , proxies=proxies)
    content = r.content
    soup = BeautifulSoup(content)
    # print(soup.encode('utf-8')) # uncomment this in case there is some non UTF-8 character in the content and
    # you get error

    for d in soup.findAll(
        "div",
        attrs={
            "class": "sg-col-4-of-12 sg-col-8-of-16 sg-col-16-of-24 sg-col-12-of-20 sg-col-24-of-32 sg-col sg-col-28-of-36 sg-col-20-of-28"
        },
    ):
        name = d.find(
            "span", attrs={"class": "a-size-medium a-color-base a-text-normal"}
        )
        price = d.find("span", attrs={"class": "a-offscreen"})
        rating = d.find("span", attrs={"class": "a-icon-alt"})
        all = []

        if name is not None:
            all.append(name.text)
        else:
            all.append("unknown-product")

        if price is not None:
            all.append(price.text)
        else:
            all.append("$0")

        if rating is not None:
            all.append(rating.text)
        else:
            all.append("-1")
        q.put(all)
        # print("---------------------------------------------------------------")


results = []
if __name__ == "__main__":
    m = Manager()
    q = (
        m.Queue()
    )  # use this manager Queue instead of multiprocessing Queue as that causes error
    p = {}
    if sys.argv[1] in [
        "t",
        "p",
    ]:  # user decides which method to invoke: thread, process or pool
        for i in range(1, no_pages):
            if sys.argv[1] in ["t"]:
                print("starting thread: ", i)
                p[i] = threading.Thread(target=get_data, args=(i, q))
                p[i].start()
            elif sys.argv[1] in ["p"]:
                print("starting process: ", i)
                p[i] = Process(target=get_data, args=(i, q))
                p[i].start()
        # join should be done in seperate for loop
        # reason being that once we join within previous for loop, join for p1 will start working
        # and hence will not allow the code to run after one iteration till that join is complete, ie.
        # the thread which is started as p1 is completed, so it essentially becomes a serial work instead of
        # parallel
        for i in range(1, no_pages):
            p[i].join()
    else:
        pool_tuple = [(x, q) for x in range(1, no_pages)]
        with Pool(processes=8) as pool:
            print("in pool")
            results = pool.starmap(get_data, pool_tuple)

    while q.empty() is not True:
        qcount = qcount + 1
        queue_top = q.get()
        products.append(queue_top[0])
        prices.append(queue_top[1])
        ratings.append(queue_top[2])

    print(
        "total time taken: ", str(time.time() - startTime), " qcount: ", qcount
    )
    # print(q.get())
    df = pd.DataFrame(
        {"Product Name": products, "Price": prices, "Ratings": ratings}
    )
    print(df)
    df.to_csv("products.csv", index=False, encoding="utf-8")



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from typing import Sequence

# from sys import stdout
# from os import linesep as NL, environ as ENV
# from platform import platform
# from io import TextIOWrapper
# from dataclasses import dataclass

# TODO profile and compare with RE and C functions


def isutf8(f):
    # TODO - create a function version of `isutf8 -li *`
    pass


# Reference: these 'string' versions without RE are from this link:
# https://stackoverflow.com/a/48350803
def replace_all(needle: Sequence,
                haystack: Sequence,
                volunteer: Sequence = "") -> (Sequence):
    """ return a sequence with all `needles` in `haystack` replaced with `volunteers` """
    return "".join(volunteer if c in needle else c for c in haystack)


def rep_whitelist(needle: Sequence,
                  haystack: Sequence,
                  volunteer: Sequence = "") -> (Sequence):
    """ return a sequence with all `needles` in `haystack` saved and all other characters replaced with `volunteers` """
    return "".join(volunteer if c not in needle else c for c in haystack)


def make_safe_id(haystack: Sequence, volunteer: Sequence = "_") -> (Sequence):
    """ return a string that  only alphanumeric and _ characters.

        others are replaced with `volunteer` (default `_`) """
    return "".join(volunteer if not c.isidentifier() else c for c in haystack)


def my_list(list):
    """ shortened version of `join` method """
    @property
    def join(self, s=" "):
        return s.join(self).strip()



from dataclasses import dataclass
from os import linesep as NL
from typing import Dict, Final, Tuple

from autosys.text_utils.datetime import *
from autosys.text_utils.datetime import _check_date_fields, _check_tzinfo_arg
from autosys.text_utils.datetime import datetime as dt


class NowAndThenError(Exception):
    """ An error in the NowAndThen datetime processing has occurred. """


@dataclass
class NowAndThen(dt):
    """ Partial wrapper for datetime to allow easy access to current
        information.

        (Methods calls are based on 'datetime.today()')

        common types from 'datetime':
            date, time, datetime (all are immutable and hashable)

        common methods, etc from 'datetime':
            basic:          date, time, now, today
            detailed:       hour, minute, second, month, day, year, weekday
            formatting:     strftime, strptime, timestamp, timetuple

        All objects are assumed to be tz naive for this implementation,
        but the method 'is_aware' was added to check as needed.
    """

    def is_aware(self, obj: (datetime, datetime.time)) -> (bool, None):
        """ Return True if an object is tz 'aware' or False if 'naive'.
            (All other objects will report an error.)

            obj = a 'datetime' or 'time' object

            (Date and time objects may be categorized as “aware” or “naive”
            depending on whether or not they include timezone information.)
            """
        if isinstance(obj, datetime):
            return obj.tzinfo is not None and obj.tzinfo.utcoffset(obj) is not None
        if isinstance(obj, datetime.time):
            return obj.tzinfo is not None and obj.tzinfo.utcoffset(None) is not None
        raise NowAndThenError(
            f"The object '{obj}' is not capable of time zone awareness"
        )

    def __getattribute__(self, name):
        return self.today().__getattribute__(name)

    def get_copyright_date(
        self, start_year: int = 0, _author: str = "", symbol: str = "(c)",
    ) -> (str):
        """ Return a correct formatted copyright string. """
        try:  # if start year is not an integer, fix it
            start_year = int(start_year)
        except:
            start_year = self.year

        if 1900 < start_year < self.year:  # is start year in (1900-now)?
            return f"Copyright {symbol} {start_year}-{self.year} {_author}"
        else:
            start_year = self.year
            return f"Copyright {symbol} {self.year} {_author}"


now = NowAndThen

# print(now())
print(now.date)
print(now.time)
# print(now.week())


def guts(obj=None):
    return obj. + ", ".join(_ for _ in dir(obj) if not _.startswith("_"))


def help(obj=None):
    return obj.__doc__


def p(obj):
    print(guts(obj=obj))


print()
p(0)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
""" Part of the `AutoSys` package - utilities for macOS apps
        copyright (c) 2019 Michael Treanor
        https://www.github.com/skeptycal/autosys
        https://www.twitter.com/skeptycal

    `AutoSys` is licensed under the `MIT License
        `<https://opensource.org/licenses/MIT>`
    """

# These color mappings were taken from matplotlib
# https://github.com/matplotlib/matplotlib/blob/master/lib/matplotlib/_color_data.py
# matplotlib license:
#   https://matplotlib.org/users/license.html
# the matplotlib license is a BSD and GPL compatible license based on the PSF license:

# PSF license:
#   https://docs.python.org/3/license.html

# Note: GPL-compatible doesn’t mean that we’re distributing Python under the
# GPL. All Python licenses, unlike the GPL, let you distribute a modified
# version without making your changes open source. The GPL-compatible licenses
# make it possible to combine Python with other software that is released
# under the GPL; the others don’t.

# matplotlib 'single letter colors' called BASE_COLORS
BASE_COLORS = {
    "b": (0, 0, 1),  # blue
    "g": (0, 0.5, 0),  # green
    "r": (1, 0, 0),  # red
    "c": (0, 0.75, 0.75),  # cyan
    "m": (0.75, 0, 0.75),  # magenta
    "y": (0.75, 0.75, 0),  # yellow
    "k": (0, 0, 0),  # black
    "w": (1, 1, 1),  # white
}



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
"""
import importlib
import sys
from timeit import timeit
from typing import List


def json1():
    import json


def json2():
    import ujson


def json3():
    import rapidjson


def json4():
    import ujson_x


def json5():
    import nujson


# def json6():
#     import autosys_json


if __name__ == "__main__":
    json_import_list: List[str] = ['simplejson', 'json', 'ujson', 'ujson-x', ]
    for json_import in json_import_list:
        try:
            importlib.
            import json_import as json
        except ImportError as e:
            print(e)
            continue


# module replacements
# Reference: https://pypi.org/project/speed-stack/#files
def _replace(replacement: str, target: str) -> bool:
    try:
        import sys
        if target in sys.modules:
            del sys.modules[target]
        sys.modules[target] = __import__(replacement)
        return True
    except:
        return False


def _hook():
    try:
        import uvloop
        import asyncio
        asyncio.set_event_loop_policy(uvloop.EventLoopPolicy())
    except:
        pass

    if not _replace("ujson", "json"):
        _replace("rapidjson", "json")
    _replace("dill", "pickle")
    _replace("multiprocess", "multiprocessing")


try:
    _hook()
except:
    pass



#!/usr/bin/env python3
# -*- coding: UTF-8 -*-

import sys


# * >>-------------------------------->> Exception utilities.

def produce_exception(recursion_level=2):
    sys.stdout.flush()
    if recursion_level:
        produce_exception(recursion_level - 1)
    else:
        raise RuntimeError()


def call_function(f, recursion_level=2):
    if recursion_level:
        return call_function(f, recursion_level - 1)
    else:
        return f()


# * >>-------------------------------->> Base Package Exception


class Error(Exception):
    """ Base error class for subclassign. """

    def __init__(self, message):
        self.message = message

        Exception.__init__(self, message)


# * >>-------------------------------->> Specific Package Exceptions

class SetupError(ValueError):
    """ An error occurred with the module setup parameters. """
    pass


class Re_File_Error(ValueError):
    """ There was a file error while attempting to match the pattern. """
    pass


class Re_Value_Error(ValueError):
    """ A regex matching error occurred. """
    pass


class BaseFileError(IOError):
    """ There was a problem initializing the file object. """
    pass


# * >>----------------------------------->> bump2version exceptions
# from https://github.com/c4urself/bump2version

class IncompleteVersionRepresentationException(Error):
    pass


class MissingValueForSerializationException(Error):
    pass


class WorkingDirectoryIsDirtyException(Error):
    pass


class MercurialDoesNotSupportSignedTagsException(Error):
    pass


if True:  # * >>---------------------------->> python 3.8 regex base exception
    pass
    '''
    # The regex exception.
    class error(Exception):
        """Exception raised for invalid regular expressions.

        Attributes:

            msg: The unformatted error message
            pattern: The regular expression pattern
            pos: The position in the pattern where compilation failed, or None
            lineno: The line number where compilation failed, unless pos is None
            colno: The column number where compilation failed, unless pos is None
        """

        def __init__(self, message, pattern=None, pos=None):
            newline = "\n" if isinstance(pattern, str) else b"\n"
            self.msg = message
            self.pattern = pattern
            self.pos = pos
            if pattern is not None and pos is not None:
                self.lineno = pattern.count(newline, 0, pos) + 1
                self.colno = pos - pattern.rfind(newline, 0, pos)

                message = "{} at position {}".format(message, pos)

                if newline in pattern:
                    message += " (line {}, column {})".format(self.lineno, self.colno)

            Exception.__init__(self, message)
        '''



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
""" # TODO -- @update `AutoSys` package
        copyright (c) 2018 Michael Treanor
        https://www.github.com/skeptycal/autosys
        https://www.twitter.com/skeptycal

    `AutoSys` is licensed under the `MIT License
        `<https://opensource.org/licenses/MIT>`


    String CONSTANTS

        ord(NL):  10

        [ord(x) for x in STR_WHITESPACE]=[32, 9, 10, 13, 11, 12]

        STR_HEX='0123456789abcdefABCDEF'`

        STR_ALPHA='abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ'

        STR_ALPHANUMERIC='abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789'

        STR_PUNCTUATION='!"#$%&\'()*+,-./:;<=>?@[\\]^_`{|}~'

        STR_PRINTABLE='0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ!"#$%&\'()*+,-./:;<=>?@[\\]^_`{|}~ \t\n\r\x0b\x0c'

        [ord(x) for x in STR_PRINTABLE]=[48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 58, 59, 60, 61, 62, 63, 64, 91, 92, 93, 94, 95, 96, 123, 124, 125, 126, 32, 9, 10, 13, 11, 12]
        """

# * --------------------------------- Imports and Constants

# 'Standard Library'
from dataclasses import Field, dataclass, field
from os import linesep

# 'package imports'
from autosys.debug.show_all import show_all
from random_string import *

from typing import Final, List, Tuple

__all__: List[str] = [
    "CASE_LIST",
    "NL",
    "NUL",
    "STR_ALPHA",
    "STR_ALPHANUMERIC",
    "STR_HEX",
    "STR_NAMES",
    "STR_PRINTABLE",
    "STR_PUNCTUATION",
    "STR_WHITESPACE",
    "StrWrapper",
    "Strang",
    "random_string",
    "string",
]

CASE_LIST: Tuple[str] = ("upper", "lower", "title", "snake", "camel", "pascal")


@dataclass
class StrWrapper:
    """ Generic Wrapper for common Python3 strings.

        :normalize: flag to strip extra whitespace. (default True)

        Contains functions to split, sub, and change case.

        Example:

        ```
        string:         spaces all over the places
        repr:      StrWrapper(string='spaces all over the places')
        split:     ['spaces', 'all', 'over', 'the', 'places']
        sub:       spaces_all_over_the_places
        upper:     SPACES ALL OVER THE PLACES
        lower:     spaces all over the places
        title:     Spaces All Over The Places
        snake:     spaces_all_over_the_places
        kebab:     spaces-all-over-the-places
        camel:     SpacesAllOverThePlaces
        pascal:    spacesAllOverThePlaces
        clear:     spacesallovertheplaces
        ```
        """

    string: str = ""
    normalize: bool = True

    def __post_init__(self):
        if self.normalize:
            # remove leading / trailing whitespace
            self.string = self.string.strip()
            self.dedupe_whitespace()
        self._set_cases()

    def __str__(self):
        return self.string

    def _set_cases(self):
        """ # TODO not yet implemented
            Choose a case by mapping the prefix to the methods.

            e.g.
            ```
            CASE_LIST = ('upper', 'lower', 'title', 'snake', 'camel', 'pascal')

            _cases = {x: f"self.to_{x}_case" for x in CASE_LIST}
            ```
            """

        self._cases = {x: f"self.to_{x}_case" for x in CASE_LIST}

    @property
    def to_upper_case(self):
        return self.string.upper()

    @property
    def to_lower_case(self):
        return self.string.lower()

    @property
    def to_title_case(self):
        return self.string.title()

    @property
    def to_snake_case(self):
        return self.sub_it().lower()

    @property
    def to_kebab_case(self):
        return self.sub_it(pattern=" _", repl="-").lower()

    @property
    def to_camel_case(self):
        return f"{self.string[0].lower()}{''.join([word.title() for word in self.string.split()])[1:]}"

    @property
    def to_pascal_case(self):
        return "".join([word.title() for word in self.string.split()])

    def split_it(self, delimiter: str = " ") -> (List[str]):
        """ Return a list of strings formed by spliting a string on each 'delimiter' using python3 built-ins. """
        return self.string.split(sep=delimiter)

    def sub_it(self, pattern: str = " -", repl="_") -> (str, None, Exception):
        """ Return a string with elements of `pattern` replaced with `repl` using python3 built-ins. """
        retval: str = ""
        for c in self.string:
            if c in pattern:
                c = repl
            retval += c
        return retval

    def dedupe_whitespace(self):
        """ Remove duplicate whitespace. """
        self.string = " ".join(self.string.split())
        return self.string


@dataclass
class Strang(StrWrapper):
    """ Wrapper for common Python3 Built-in String Utilities. """
    def __post_init__(self):
        super().__post_init__()

    def pip_safe_name(self) -> (str):
        """ Return a name that is converted to pypi safe format.

            Replace ' ' (space) and '-'(hyphen) with _(underscore) using python3 built-ins
            """
        return self.string.lower().replace("- ", "_")

    def clear_all_whitespace(self):
        return self.string.translate({ord(c): None for c in string.whitespace})
        # TODO - which is faster?
        # self.string = "".join(self.string.split())



#!/usr/bin/env python3
# -*- coding: UTF-8 -*-

# 'Standard Library'
import pathlib

# remove xxx to use this list
file_list_xxx = [
    "/usr/local/lib/libcdt.la",
    "/usr/local/lib/libcgraph.la",
    "/usr/local/lib/libgcrypt.la",
    "/usr/local/lib/libgpg-error.la",
    "/usr/local/lib/libgvc.la",
    "/usr/local/lib/libgvpr.la",
    "/usr/local/lib/libksba.la",
    "/usr/local/lib/liblab_gamut.la",
    "/usr/local/lib/libnpth.la",
    "/usr/local/lib/libntbtls.la",
    "/usr/local/lib/libpathplan.la",
    "/usr/local/lib/libxdot.la",
]


def del_file_list(file_list):
    for file in file_list:
        p = pathlib.Path(file)
        if p.is_file():
            print(p.name)
            p.unlink()


def main():
    """
    CLI script main entry point.
    """
    del_file_list(file_list=file_list)


if __name__ == "__main__":  # if script is loaded directly from CLI
    main()



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
""" flask_keygen.py """
# copyright (c) 2019 Michael Treanor
# https://www.github.com/skeptycal

# 'Standard Library'
import secrets

flask_key: bytes = secrets.token_bytes(24)

if __name__ == "__main__":
    key_str: str = str(flask_key)
    print("")
    print("*" * 79)
    print("New, unique FLASK_SECRET_KEY generated: ")
    print("")
    print(" bytes: ", flask_key)
    print("string: ", key_str)
    print("")

# References:
#   modifications to dev cycle and file structure inspired by:
#       https://github.com/aeroxis/sultan
#   Reference for FLASK_SECRET_KEY:
#       https://stackoverflow.com/questions/22463939/demystify-flask-app-secret-key



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
""" BasicColors - basic ANSI CLI colors

    Part of the `AutoSys` package - utilities for macOS apps
        copyright (c) 2019 Michael Treanor
        https://www.github.com/skeptycal/autosys
        https://www.twitter.com/skeptycal

    `AutoSys` is licensed under the `MIT License
        `<https://opensource.org/licenses/MIT>`
    """

try:
    SUPPORTS_COLOR == True
except:
    try:
        from cli import SUPPORTS_COLOR
    except:
        SUPPORTS_COLOR: bool = False

print(SUPPORTS_COLOR)
# some basic CLI colors ..
class BasicColors:
    MAIN: str = "\x1B[38;5;229m" * SUPPORTS_COLOR
    WARN: str = "\x1B[38;5;203m" * SUPPORTS_COLOR
    BLUE: str = "\x1B[38;5;38m" * SUPPORTS_COLOR
    GO: str = "\x1B[38;5;28m" * SUPPORTS_COLOR
    CHERRY: str = "\x1B[38;5;124m" * SUPPORTS_COLOR
    CANARY: str = "\x1B[38;5;226m" * SUPPORTS_COLOR
    ATTN: str = "\x1B[38;5;178m" * SUPPORTS_COLOR
    RAIN: str = "\x1B[38;5;93m" * SUPPORTS_COLOR
    WHITE: str = "\x1B[37m" * SUPPORTS_COLOR
    RESET: str = "\x1B[0m" * SUPPORTS_COLOR



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# Prints today's date
# 'Standard Library'
from datetime import date, datetime, time

# 'package imports'
from autosys.cli.debug import br, dbprint, hr

# Days start at 0 for monday
days = [
    "monday",
    "tuesday",
    "wednesday",
    "thursday",
    "friday",
    "saturday",
    "sunday",
]


class int_restricted(int):
    pass


class DT(datetime):
    def __init__(self):
        self.dt = datetime.now()

    @property
    def today(self):
        return self.dt.today()

    @property
    def now(self):
        return f"{self.today:%H:%M %p}"

    def __str__(self):
        return f"{self.today:%B %d, %Y}"


def main():
    # DATETIME OBJECTS
    # Get today's date from datetime class
    today = datetime.now()
    print(today)
    # Get the current time
    t = datetime.time(datetime.now())
    print("The current time is", t)
    # weekday returns 0 (monday) through 6 (sunday)
    wd = date.weekday(today)

    print("Today is day number %d" % wd)
    print("which is a " + days[wd])

    print()
    # instance of DT class for testing
    dt = DT()

    print(bool.__bases__)
    print(f"{dt=}")
    print(f"dt: {dt}")
    br()
    print(f"{dt.today=}")
    print(dt.now)
    print(f"{dt.today:%B %d, %Y}")


if __name__ == "__main__":
    main()
